@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.31.2.2 2001/02/25 12:30:22 bazsi Exp $
+ * $Id: affile.c,v 1.31.2.4 2001/07/11 14:08:16 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -108,7 +108,7 @@ static int do_init_affile_source(struct log_handler *c, struct syslog_config *cf
 		struct resource_node *res;
 
 		lseek(fd, 0, SEEK_END);
-		self->src = io_read(make_io_fd(cfg->backend, fd), 
+		self->src = io_read(make_io_fd(cfg->backend, fd, NULL), 
 			make_log_reader(0, c), 
 			NULL);
 		res = REMEMBER_RESOURCE(cfg->resources, &self->src->super.super);
@@ -208,7 +208,7 @@ do_init_dest_writer(struct log_handler *c, struct syslog_config *cfg, struct per
 	                 self->owner->flags & AFFILE_CREATE_DIRS, &fd)) {
 
 		self->dest = 
-			io_write(make_io_fd(cfg->backend, fd), 
+			io_write(make_io_fd(cfg->backend, fd, NULL), 
 				 make_pkt_buffer_ext(self->owner->sync_freq, 
 				                     MAX(self->owner->super.log_fifo_size + 1, 
 					                 self->owner->sync_freq)),
@@ -428,6 +428,7 @@ void expand_macro(struct syslog_config *cfg, int id, char **dest, int *left, str
 
 		break;
 	}
+	case 'w':
 	case 'y':
 	case 'm':
 	case 'd': 
@@ -460,6 +461,9 @@ void expand_macro(struct syslog_config *cfg, int id, char **dest, int *left, str
 		case 'S':
 			length = snprintf(*dest, *left, "%02d", tm->tm_sec);
 			break;
+		case 'w':
+			length = strftime(*dest, *left - 1, "%a", tm);
+			break;
 		}
 		break;
 	}
@@ -484,7 +488,8 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, struct log_
 		{ "DAY", 'd' },
 		{ "HOUR", 'H' },
 		{ "MIN", 'M' },
-		{ "SEC", 'S' }
+		{ "SEC", 'S' },
+		{ "WEEKDAY", 'w' }
 	};
 	char format[MAX_EXPANDED_MACRO], *format_ptr = format;
 	int left = sizeof(format);
