@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.6.4.3 2001/07/11 14:08:16 bazsi Exp $
+ * $Id: afinet.c,v 1.6.4.4 2001/10/19 12:44:59 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -427,6 +427,10 @@ static int do_init_afinet_dest(struct log_handler *c,
 	}
 	else {
 		werror("Error creating AF_INET socket (%z)\n", strerror(errno));
+		
+		io_callout(self->cfg->backend,
+		           self->cfg->time_reopen,
+		           make_driver_reinit(&self->super.super.super, self->cfg));
 	}
 	return ST_FAIL | ST_QUIT;
 }
